package
Version:
v0.0.0-...-cc9b1f3
Opens a new window with list of versions in this module.
Published: Jul 4, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Client is used to manage redis client
New creates a redis client
Close closes redis Client
GetLock gets a lock of redis lock. If redis is not available, a local lock is gotten
type Config struct {
Addrs []string `json:"Addrs"`
Username string `json:"Username"`
Password string `json:"Password"`
}
Config describes the configuration of redis
Source Files
¶
Click to show internal directories.
Click to hide internal directories.